==> qmmp-0.6.8.tar.bz2: qmmp-0.6.8/src/plugins/General/notifier/translations/notifier_plugin_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>NotifierFactory</name>
    <message>
        <location filename="../notifierfactory.cpp" line="30"/>
        <source>Notifier Plugin</source>
        <translation>Wtyczka Notifier</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="50"/>
        <source>About Notifier Plugin</source>
        <translation>O wtyczce Notifier</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="51"/>
        <source>Qmmp Notifier Plugin</source>
        <translation>Wtyczka Notifier dla Qmmp</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>PopupWidget</name>
    <message>
        <location filename="../popupwidget.cpp" line="127"/>
        <source>Volume:</source>
        <translation>Głośność:</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Notifier Plugin Settings</source>
        <translation>Ustawienia wtyczki Notifier</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="141"/>
        <source>Transparency:</source>
        <translation>Przezroczystość:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="105"/>
        <source>Notification Template</source>
        <translation>Szablon powiadomienia</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="368"/>
        <source>Psi Notification</source>
        <translation>Powiadomienia Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="380"/>
        <source>Enable Psi notification</source>
        <translation>Włącz powiadomienia Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Desktop Notification</source>
        <translation>Powiadomienie na pulpicie</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Song change notification</source>
        <translation>Pozycja</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Volume change notification</source>
        <translation>Powiadamianie o zmianie głośności</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="134"/>
        <location filename="../settingsdialog.ui" line="164"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="321"/>
        <source>Position</source>
        <translation>Pozycja</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="343"/>
        <source>Edit template</source>
        <translation>Edytuj szablon</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Font:</source>
        <translation>Czcionka:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="108"/>
        <source>Cover size:</source>
        <translation>Wielkość okładki:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="82"/>
        <source>Delay (ms):</source>
        <translation>Opóźnienie (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <source>...</source>
        <translation></translation>
    </message>
</context>
</TS>

==> qmmp-0.7.5.tar.bz2: qmmp-0.7.5/src/plugins/General/notifier/translations/notifier_plugin_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>NotifierFactory</name>
    <message>
        <location filename="../notifierfactory.cpp" line="30"/>
        <source>Notifier Plugin</source>
        <translation>Wtyczka Notifier</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="50"/>
        <source>About Notifier Plugin</source>
        <translation>O wtyczce Notifier</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="51"/>
        <source>Qmmp Notifier Plugin</source>
        <translation>Wtyczka Notifier dla Qmmp</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>PopupWidget</name>
    <message>
        <location filename="../popupwidget.cpp" line="127"/>
        <source>Volume:</source>
        <translation>Głośność:</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Notifier Plugin Settings</source>
        <translation>Ustawienia wtyczki Notifier</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="141"/>
        <source>Transparency:</source>
        <translation>Przezroczystość:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="105"/>
        <source>Notification Template</source>
        <translation>Szablon powiadomienia</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="368"/>
        <source>Psi Notification</source>
        <translation>Powiadomienia Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="380"/>
        <source>Enable Psi notification</source>
        <translation>Włącz powiadomienia Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Desktop Notification</source>
        <translation>Powiadomienie na pulpicie</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Song change notification</source>
        <translation>Powiadamianie o zmianie utworu</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Volume change notification</source>
        <translation>Powiadamianie o zmianie głośności</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="134"/>
        <location filename="../settingsdialog.ui" line="164"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="321"/>
        <source>Position</source>
        <translation>Pozycja</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="343"/>
        <source>Edit template</source>
        <translation>Edytuj szablon</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Font:</source>
        <translation>Czcionka:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="108"/>
        <source>Cover size:</source>
        <translation>Rozmiar okładki:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="82"/>
        <source>Delay (ms):</source>
        <translation>Opóźnienie (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <source>...</source>
        <translation></translation>
    </message>
</context>
</TS>
